Crate basecoat_css

Crate basecoat_css 

Component-layer CSS for basecoat-rs.

Drop into a Tailwind v4 pipeline via @import or write to disk and reference the file from your build.

Examples

use std::path::Path;
basecoat_css::write_to(Path::new("style/basecoat.css")).unwrap();

Constants

SOURCE
The full basecoat-css source as a &'static str.

Functions

write_to
Write the source to path, overwriting if it exists.